about summary refs log tree commit diff
path: root/argp/argp-help.c
diff options
context:
space:
mode:
authorOndřej Bílka <neleai@seznam.cz>2013-08-29 09:08:54 +0200
committerOndřej Bílka <neleai@seznam.cz>2013-08-29 09:11:45 +0200
commit6f65e668957a50e153cba6822f747d13ad1b40ad (patch)
treedec30aa85e57419ac1eafffeab8548c973cac02f /argp/argp-help.c
parentd0721e703d222c01a9e8c329311c4fb01dac6972 (diff)
downloadglibc-6f65e668957a50e153cba6822f747d13ad1b40ad.tar.gz
glibc-6f65e668957a50e153cba6822f747d13ad1b40ad.tar.xz
glibc-6f65e668957a50e153cba6822f747d13ad1b40ad.zip
Fix typos.
Diffstat (limited to 'argp/argp-help.c')
-rw-r--r--argp/argp-help.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/argp/argp-help.c b/argp/argp-help.c
index 53702e3dd2..ace71b48c2 100644
--- a/argp/argp-help.c
+++ b/argp/argp-help.c
@@ -160,7 +160,7 @@ static const struct uparam_name uparam_names[] =
 };
 #define nuparam_names (sizeof (uparam_names) / sizeof (uparam_names[0]))
 
 /* Read user options from the environment, and fill in UPARAMS appropiately.  */
 static void
 fill_in_uparams (const struct argp_state *state)
 {
@@ -275,11 +275,11 @@ fill_in_uparams (const struct argp_state *state)
      -xARG, -yARG, --long1=ARG, --long2=ARG        Documentation...
 
    Where ARG will be omitted if there's no argument, for this option, or
-   will be surrounded by "[" and "]" appropiately if the argument is
-   optional.  The documentation string is word-wrapped appropiately, and if
+   will be surrounded by "[" and "]" appropriately if the argument is
+   optional.  The documentation string is word-wrapped appropriately, and if
    the list of options is long enough, it will be started on a separate line.
    If there are no short options for a given option, the first long option is
-   indented slighly in a way that's supposed to make most long options appear
+   indented slightly in a way that's supposed to make most long options appear
    to be in a separate column.
 
    For example, the following output (from ps):
@@ -998,7 +998,7 @@ filter_doc (const char *doc, int key, const struct argp *argp,
     return doc;
 }
 
 /* Prints STR as a header line, with the margin lines set appropiately, and
    notes the fact that groups should be separated with a blank line.  ARGP is
    the argp that should dictate any user doc filtering to take place.  Note
    that the previous wrap margin isn't restored, but the left margin is reset
@@ -160,7 +160,7 @@ static const struct uparam_name uparam_names[] =
 #define nuparam_names (sizeof (uparam_names) / sizeof (uparam_names[0]))
 
-/* Read user options from the environment, and fill in UPARAMS appropiately.  */
+/* Read user options from the environment, and fill in UPARAMS appropriately.  */
 static void
 fill_in_uparams (const struct argp_state *state)
@@ -998,7 +998,7 @@ filter_doc (const char *doc, int key, const struct argp *argp,
 }
 
-/* Prints STR as a header line, with the margin lines set appropiately, and
+/* Prints STR as a header line, with the margin lines set appropriately, and
    notes the fact that groups should be separated with a blank line.  ARGP is
    the argp that should dictate any user doc filtering to take place.  Note